@@ -17,7 +17,7 @@ def intepreter_header():
 
 
 def func_query_format():
-    return [INPUT_PREFIX + "1\n", "1\n"]
+    return [INPUT_PREFIX + "1+1\n", "2\n"]
 
 
 def func_definition(func_def, input_prefix=INPUT_PREFIX):
@@ -29,7 +29,7 @@ def func_definition(func_def, input_prefix=INPUT_PREFIX):
         input_prefix
         + INDENT_REGEX.match(prompts[-1][len(input_prefix) :]).group()
         #  + "[...Implementation Omitted...]\n"
-        + f"return _{func_def.intension.name}(*locals())\n"  # TODO
+        + f"_{func_def.intension.name}(*locals())\n"  # TODO
     )
     prompts.append(input_prefix + "\n")
     return prompts
